@@ -1,12 +1,12 @@
 /*
-** Copyright (C) 1991, 1997-2017,2019 Free Software Foundation, Inc.
+** Copyright 2017-2020,2021 Thomas E. Dickey
+** Copyright 1997-2015,2017 Free Software Foundation, Inc.
 **
 ** This file is part of TACK.
 **
 ** TACK is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2, or (at your option)
-** any later version.
+** the Free Software Foundation, version 2.
 **
 ** TACK is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,7 +19,7 @@
 ** Boston, MA 02110-1301, USA
 */
 
-/* $Id: tack.h,v 1.74 2019/07/21 19:08:15 tom Exp $ */
+/* $Id: tack.h,v 1.91 2021/06/19 21:28:22 tom Exp $ */
 
 #ifndef NCURSES_TACK_H_incl
 #define NCURSES_TACK_H_incl 1
@@ -27,8 +27,8 @@
 /* terminfo action checker include file */
 
 #define MAJOR_VERSION 1
-#define MINOR_VERSION 8
-#define PATCH_VERSION 20190721
+#define MINOR_VERSION 9
+#define PATCH_VERSION 20210619
 
 #ifdef HAVE_CONFIG_H
 #include <ncurses_cfg.h>
@@ -55,7 +55,11 @@
 #endif
 
 #ifndef NCURSES_CONST
+#ifdef NCURSES_VERSION
 #define NCURSES_CONST const
+#else
+#define NCURSES_CONST		/*nothing */
+#endif
 #endif
 
 #ifndef NO_LEAKS
@@ -127,10 +131,10 @@
 extern void tack_edit_leaks(void);
 extern void tack_fun_leaks(void);
 #ifdef HAVE__NC_FREE_TINFO
-extern void _nc_free_tinfo(int) GCC_NORETURN;
+extern GCC_NORETURN void _nc_free_tinfo(int);
 #endif
 #ifndef ExitProgram
-extern void ExitProgram(int) GCC_NORETURN;
+extern GCC_NORETURN void ExitProgram(int);
 #endif
 #else
 #define ExitProgram(code) exit(code)
@@ -201,10 +205,11 @@ typedef enum {
 } NAME_TYPE;
 
 /* see ncurses' nc_tparm.h */
+#define TPARM_FMT NCURSES_CONST char *
 #define TPARM_ARG long
 #define TPARM_N(n) (TPARM_ARG)(n)
 
-#define TPARM_9(a,b,c,d,e,f,g,h,i,j) tparm(a,TPARM_N(b),TPARM_N(c),TPARM_N(d),TPARM_N(e),TPARM_N(f),TPARM_N(g),TPARM_N(h),TPARM_N(i),TPARM_N(j))
+#define TPARM_9(a,b,c,d,e,f,g,h,i,j) tparm((TPARM_FMT)a,TPARM_N(b),TPARM_N(c),TPARM_N(d),TPARM_N(e),TPARM_N(f),TPARM_N(g),TPARM_N(h),TPARM_N(i),TPARM_N(j))
 #define TPARM_8(a,b,c,d,e,f,g,h,i) TPARM_9(a,b,c,d,e,f,g,h,i,0)
 #define TPARM_7(a,b,c,d,e,f,g,h) TPARM_8(a,b,c,d,e,f,g,h,0)
 #define TPARM_6(a,b,c,d,e,f,g) TPARM_7(a,b,c,d,e,f,g,0)
@@ -213,7 +218,6 @@ typedef enum {
 #define TPARM_3(a,b,c,d) TPARM_4(a,b,c,d,0)
 #define TPARM_2(a,b,c) TPARM_3(a,b,c,0)
 #define TPARM_1(a,b) TPARM_2(a,b,0)
-#define TPARM_1(a,b) TPARM_2(a,b,0)
 #define TPARM_0(a) TPARM_1(a,0)
 
 #define UChar(c)    ((unsigned char)(c))
@@ -221,6 +225,9 @@ typedef enum {
 #define NAME_SIZE 32
 #define TEMP_SIZE 1024
 
+#define LOG_FILENAME "tack.log"
+#define DBG_FILENAME "debug.log"
+
 extern FILE *log_fp;
 extern FILE *debug_fp;
 extern int debug_level;
@@ -253,6 +260,7 @@ extern int raw_characters_sent;	/* Total output characters */
 
 /* definitions for pad.c */
 
+#define ENSURE_DELAY  if (!tt_delay_used) napms(10)
 #define EXIT_CONDITION (no_alarm_event && (tt_delay_used < tt_delay_max))
 #define SLOW_TERMINAL_EXIT if (!test_complete && !EXIT_CONDITION) { break; }
 #define CAP_NOT_FOUND if (auto_pad_mode) return
@@ -459,10 +467,12 @@ extern char *hex_expand_to(char *, int);
 extern char *print_expand(char *);
 extern int getchp(int);
 extern int getnext(int);
+extern int log_chr(FILE *, int, int);
 extern int tc_putp(const char *);
 extern int wait_here(void);
 extern void go_home(void);
 extern void home_down(void);
+extern void log_str(FILE *, const char *);
 extern void maybe_wait(int);
 extern void ptext(const char *);
 extern void ptextln(const char *);
@@ -470,7 +480,6 @@ extern void put_clear(void);
 extern void put_columns(const char *, int, int);
 extern void put_cr(void);
 extern void put_crlf(void);
-extern void put_dec(char *, int);
 extern void put_ind(void);
 extern void put_lf(void);
 extern void put_newlines(int);
@@ -479,7 +488,6 @@ extern void put_this(int);
 extern void putchp(int);
 extern void putln(const char *);
 extern void read_string(char *, size_t);
-extern void three_digit(char *, int);
 extern void tt_putp(const char *);
 extern void tt_putparm(NCURSES_CONST char *, int, int, int);
 extern void tt_tputs(const char *, int);
